#!/usr/bin/python3

import argparse
import configparser
import pathlib

from . import validate
from .validate import LinuxBinary, PlatformBinary, WindowsBinary


def main() -> None:
    parser = argparse.ArgumentParser()

    parser.add_argument("validation_file", metavar="config", type=pathlib.Path)

    args = parser.parse_args()

    config = configparser.ConfigParser()
    config.read(args.validation_file)

    entries = validate.read_config(config)

    linux_target = LinuxBinary(pathlib.Path("server_srv.so"))
    windows_target = WindowsBinary(pathlib.Path("server.dll"))

    linux_target.path = pathlib.Path("232250/tf/bin/server_srv.so")
    windows_target.path = pathlib.Path("232250/tf/bin/server.dll")

    candidate_targets: list[PlatformBinary] = [linux_target, windows_target]

    for name, entry in entries.items():
        target = entry.get_target_match(candidate_targets)
        assert target, f"No binary match for {entry.target}"
        try:
            for key, result in entry.process(target).items():
                print("- [OK]", key.substitute(name=name), "=", result)
        except Exception as e:
            print("- [FAIL]", name, f"({type(e).__name__}):", e)


if __name__ == "__main__":
    main()
